@@ -36,6 +36,8 @@ class Cursor(object):
     def errorhandler(self, errorclass, errorvalue):
         if self.connection:
             self.connection.errorhandler(self, errorclass, errorvalue)
+        else:
+            raise errorclass(errorvalue)
 
     @property
     def rowcount(self):
@@ -67,12 +69,12 @@ class Cursor(object):
 
     def _get_db(self):
         if not self.connection:
-            self.errorhandler(ProgrammingError, "cursor closed")
+            self.errorhandler(ProgrammingError, (-1, "cursor closed"))
         return self.connection
 
     def _check_executed(self):
         if not self._executed:
-            self.errorhandler(ProgrammingError, "execute() first")
+            self.errorhandler(ProgrammingError, (-1, "execute() first"))
 
     def _flush(self):
         if self._result:
